@@ -71,26 +71,28 @@ colsum <- function(x, group, reorder=TRUE, na.rm=FALSE, ...)
     ans
 }
 
-.BLOCK_rowsum <- function(x, group, reorder=TRUE, na.rm=FALSE, grid=NULL)
+.compute_ugroup <- function(group, expected_group_len, reorder=TRUE)
 {
-    if (is.factor(group))
-        group <- as.character(group)
-    else if (!is.vector(group))
+    if (!(is.vector(group) || is.factor(group)))
         stop(wmsg("'group' must be a vector or factor"))
-    if (length(group) != nrow(x))
+    if (length(group) != expected_group_len)
         stop(wmsg("incorrect length for 'group'"))
     if (!isTRUEorFALSE(reorder))
         stop(wmsg("'reorder' must be TRUE or FALSE"))
-    if (!isTRUEorFALSE(na.rm))
-        stop(wmsg("'na.rm' must be TRUE or FALSE"))
-
     ## Taken from base::rowsum.default().
     ugroup <- unique(group)
     if (anyNA(ugroup))
         warning(wmsg("missing values for 'group'"))
     if (reorder)
         ugroup <- sort(ugroup, na.last=TRUE, method="quick")
+    as.character(ugroup)
+}
 
+.BLOCK_rowsum <- function(x, group, reorder=TRUE, na.rm=FALSE, grid=NULL)
+{
+    ugroup <- .compute_ugroup(group, nrow(x), reorder)
+    if (!isTRUEorFALSE(na.rm))
+        stop(wmsg("'na.rm' must be TRUE or FALSE"))
     grid <- normarg_grid(grid, x)
 
     ## Outer loop on the grid columns. Parallelized.
@@ -109,24 +111,9 @@ colsum <- function(x, group, reorder=TRUE, na.rm=FALSE, ...)
 }
 .BLOCK_colsum <- function(x, group, reorder=TRUE, na.rm=FALSE, grid=NULL)
 {
-    if (is.factor(group))
-        group <- as.character(group)
-    else if (!is.vector(group))
-        stop(wmsg("'group' must be a vector or factor"))
-    if (length(group) != ncol(x))
-        stop(wmsg("incorrect length for 'group'"))
-    if (!isTRUEorFALSE(reorder))
-        stop(wmsg("'reorder' must be TRUE or FALSE"))
+    ugroup <- .compute_ugroup(group, ncol(x), reorder)
     if (!isTRUEorFALSE(na.rm))
         stop(wmsg("'na.rm' must be TRUE or FALSE"))
-
-    ## Taken from base::rowsum.default().
-    ugroup <- unique(group)
-    if (anyNA(ugroup))
-        warning(wmsg("missing values for 'group'"))
-    if (reorder)
-        ugroup <- sort(ugroup, na.last=TRUE, method="quick")
-
     grid <- normarg_grid(grid, x)
 
     ## Outer loop on the grid rows. Parallelized.
@@ -542,7 +529,7 @@ setMethod("%*%", c("DelayedMatrix", "DelayedMatrix"), .BLOCK_matrix_mult)
     MULT(block_x, block_y)
 }
 
-.super_BLOCK_mult <- function(x, y, MULT, transposed.x=FALSE, transposed.y=FALSE, BPPARAM=bpparam())
+.super_BLOCK_mult <- function(x, y, MULT, transposed.x=FALSE, transposed.y=FALSE, BPPARAM=getAutoBPPARAM())
 # Controller function that split jobs for a multiplication function "MULT".
 # This accommodates %*%, crossprod and tcrossprod for two arguments.
 {
@@ -550,9 +537,9 @@ setMethod("%*%", c("DelayedMatrix", "DelayedMatrix"), .BLOCK_matrix_mult)
     chosen_scheme <- scheme_out$choice
     chosen_grids <- scheme_out$grid
 
-    old <- bpparam()
-    on.exit(register(old))
-    register(SerialParam()) # avoid re-parallelizing in further calls to 'MULT'.
+    old <- getAutoBPPARAM()
+    on.exit(setAutoBPPARAM(old))
+    setAutoBPPARAM(SerialParam()) # avoid re-parallelizing in further calls to 'MULT'.
 
     if (chosen_scheme=="common") {
         ans <- bpiterate(.dual_grid_iterate(chosen_grids$x, chosen_grids$y), FUN=.both_mult,
@@ -622,7 +609,7 @@ setMethod("tcrossprod", c("DelayedMatrix", "DelayedMatrix"), function(x, y) .sup
     MULT(block)
 }
 
-.super_BLOCK_self <- function(x, MULT, transposed=FALSE, BPPARAM=bpparam())
+.super_BLOCK_self <- function(x, MULT, transposed=FALSE, BPPARAM=getAutoBPPARAM())
 # Controller function that split jobs for a multiplication function "MULT".
 # This accommodates crossprod and tcrossprod for single arguments.
 {
@@ -630,9 +617,9 @@ setMethod("tcrossprod", c("DelayedMatrix", "DelayedMatrix"), function(x, y) .sup
     chosen_scheme <- scheme_out$choice
     chosen_grids <- scheme_out$grid
 
-    old <- bpparam()
-    on.exit(register(old))
-    register(SerialParam()) # avoid re-parallelizing in further calls to 'MULT'.
+    old <- getAutoBPPARAM()
+    on.exit(setAutoBPPARAM(old))
+    setAutoBPPARAM(SerialParam()) # avoid re-parallelizing in further calls to 'MULT'.
 
     if (chosen_scheme=="single") {
         out <- bpiterate(.single_grid_iterate(chosen_grids), FUN=.left_mult,
