@@ -722,6 +722,36 @@ setClass("DelayedSubassign",
 
 setValidity2("DelayedSubassign", .validate_DelayedSubassign)
 
+.normarg_Rvalue <- function(Rvalue, selection_dim)
+{
+    Rvalue_dim <- dim(Rvalue)
+    if (is.null(Rvalue_dim) && !is.vector(Rvalue))
+        stop(wmsg("replacement value must be an array-like object ",
+                  "or an ordinary vector"))
+    ## 'Rvalue' is an array-like object or an ordinary vector (atomic or list).
+    if (length(Rvalue) != prod(selection_dim))
+        stop(wmsg("length of replacement value must equal the number ",
+                  "of array elements to replace"))
+    if (is.null(Rvalue_dim)) {
+        ## 'x@Rvalue' is an ordinary vector (atomic or list).
+        dim(Rvalue) <- selection_dim
+        return(Rvalue)
+    }
+    same_dims <- function(dim1, dim2) length(dim1) == length(dim2) &&
+                                      all(dim1 == dim2)
+    if (same_dims(Rvalue_dim, selection_dim))
+        return(Rvalue)
+    ## We're going to reshape 'Rvalue' but only if its effective dimensions
+    ## are the same as the effective dimensions of the selection.
+    Rvalue_effdim <- Rvalue_dim[Rvalue_dim != 1L]
+    selection_effdim <- selection_dim[selection_dim != 1L]
+    if (!same_dims(Rvalue_effdim, selection_effdim))
+        stop(wmsg("dimensions of replacement value are incompatible ",
+                  "with the selection of the subassignment"))
+    dim(Rvalue) <- selection_dim
+    Rvalue
+}
+
 ### 'Nindex' must be a "multidimensional subsetting Nindex" (see
 ### Nindex-utils.R) or NULL.
 new_DelayedSubassign <- function(seed=new("array"), Nindex=NULL, Rvalue=NA)
@@ -729,18 +759,9 @@ new_DelayedSubassign <- function(seed=new("array"), Nindex=NULL, Rvalue=NA)
     Lindex <- normalizeNindex(Nindex, seed)
     seed_dim <- dim(seed)
     nogap <- subscript_has_nogap(Lindex, seed_dim)
-    Rvalue_dim <- dim(Rvalue)
-    if (is.null(Rvalue_dim)) {
-        if (!(is.vector(Rvalue) && length(Rvalue) == 1L))
-            stop(wmsg("replacement value must be an array-like object ",
-                      "(or an ordinary vector of length 1)"))
-        ## 'x@Rvalue' is an ordinary vector (atomic or list) of length 1
-    } else {
-        ## 'x@Rvalue' is an array-like object
-        expected_Rvalue_dim <- get_Nindex_lengths(Lindex, seed_dim)
-        if (!identical(Rvalue_dim, expected_Rvalue_dim))
-            stop(wmsg("dimensions of replacement value are incompatible ",
-                      "with the number of array elements to replace"))
+    if (!(is.null(dim(Rvalue)) && is.vector(Rvalue) && length(Rvalue) == 1L)) {
+        selection_dim <- get_Nindex_lengths(Lindex, seed_dim)
+        Rvalue <- .normarg_Rvalue(Rvalue, selection_dim)
         ## For each non-NULL subscript, keep **last** duplicate only and
         ## replace all previous duplicates with NAs.
         Lindex <- lapply(Lindex,
@@ -996,20 +1017,6 @@ setClass("DelayedDimnames",
 
 setValidity2("DelayedDimnames", .validate_DelayedDimnames)
 
-### TODO: Also make sure that each 'dimnames' list element is either NULL or
-### a character vector of the correct length.
-.normalize_dimnames <- function(dimnames, ndim)
-{
-    if (is.null(dimnames))
-        return(vector("list", length=ndim))
-    if (!is.list(dimnames))
-        stop("the supplied dimnames must be a list")
-    if (length(dimnames) != ndim)
-        stop(wmsg("the supplied dimnames must have one list element ",
-                  "per dimension in the array-like object"))
-    dimnames
-}
-
 new_DelayedDimnames <- function(seed=new("array"), dimnames=.INHERIT_FROM_SEED)
 {
     seed_dim <- dim(seed)
@@ -1017,12 +1024,24 @@ new_DelayedDimnames <- function(seed=new("array"), dimnames=.INHERIT_FROM_SEED)
     if (identical(dimnames, .INHERIT_FROM_SEED)) {
         dimnames <- rep.int(list(.INHERIT_FROM_SEED), seed_ndim)
     } else {
-        dimnames <- .normalize_dimnames(dimnames, seed_ndim)
+        dimnames <- normarg_dimnames(dimnames, seed_dim)
         seed_dimnames <- dimnames(seed)
-        dimnames <- lapply(seq_len(seed_ndim),
+        dimnames <- lapply(setNames(seq_len(seed_ndim), names(dimnames)),
                            function(along) {
                                dn <- dimnames[[along]]
-                               if (identical(dn, seed_dimnames[[along]]))
+                               seed_dn <- seed_dimnames[[along]]
+                               ## Let's play nice with seeds that return
+                               ## dimnames() that are not NULL or a character
+                               ## vector e.g.
+                               ##   library(GDSArray)
+                               ##   gds <- seqExampleFileName("gds")
+                               ##   ga1 <- GDSArray(gds, "genotype/data")
+                               ##   sapply(dimnames(ga1), class)
+                               ##   #  variant.id   sample.id   ploidy.id
+                               ##   # "character" "character"   "integer"
+                               if (!(is.null(seed_dn) || is.character(seed_dn)))
+                                   seed_dn <- as.character(seed_dn)
+                               if (identical(dn, seed_dn))
                                    return(.INHERIT_FROM_SEED)
                                dn
                            })
@@ -1032,7 +1051,11 @@ new_DelayedDimnames <- function(seed=new("array"), dimnames=.INHERIT_FROM_SEED)
 
 setMethod("is_noop", "DelayedDimnames",
     function(x)
-        all(vapply(x@dimnames, identical, logical(1), .INHERIT_FROM_SEED))
+    {
+        ok <- vapply(x@dimnames, identical, logical(1), .INHERIT_FROM_SEED,
+                     USE.NAMES=FALSE)
+        all(ok) && identical(names(x@dimnames), names(dimnames(x@seed)))
+    }
 )
 
 ### S3/S4 combo for summary.DelayedDimnames
@@ -1052,7 +1075,7 @@ setMethod("summary", "DelayedDimnames", summary.DelayedDimnames)
 {
     x_dimnames <- x@dimnames
     seed_dimnames <- dimnames(x@seed)
-    ans <- lapply(seq_along(x_dimnames),
+    ans <- lapply(setNames(seq_along(x_dimnames), names(x_dimnames)),
                   function(along) {
                       dn <- x_dimnames[[along]]
                       if (identical(dn, .INHERIT_FROM_SEED))
@@ -1250,6 +1273,10 @@ new_DelayedAbind <- function(seeds, along)
     new2("DelayedAbind", seeds=seeds, along=along)
 }
 
+setMethod("is_noop", "DelayedAbind",
+    function(x) length(x@seeds) == 1L
+)
+
 ### S3/S4 combo for summary.DelayedAbind
 
 .DelayedAbind_summary <-
